@@ -1,5 +1,5 @@
 package App::rshasum;
-$App::rshasum::VERSION = '0.6.2';
+$App::rshasum::VERSION = '0.6.3';
 use 5.016;
 use strict;
 use warnings;
@@ -36,9 +36,14 @@ FILES:
         }
         if ( $r->is_file )
         {
-            my $d = Digest->new($digest);
-            open my $fh, '<', $r->path;
+            my $fh;
+            if ( not( open $fh, '<', $r->path ) )
+            {
+                warn "Could not open @{[$r->path]}; skipping";
+                next FILES;
+            }
             binmode $fh;
+            my $d = Digest->new($digest);
             $d->addfile($fh);
             close $fh;
             my $s = $d->hexdigest . '  ' . $path . "\n";
@@ -90,7 +95,7 @@ App::rshasum - recursive shasum.
 
 =head1 VERSION
 
-version 0.6.2
+version 0.6.3
 
 =head1 SYNOPSIS
 
